/*
 * Installer by Fernando Pereira Silveira
 *
 * Derived from XpiInstaller By Pike
 */

// --- EDITABLE DATA BEGIN -----------------------------------

const fullName        = "Controle de Scripts";
const shortName       = "controledescripts";
const version         = "0.5.0.1";
const locales         = ["de-DE", "en-GB", "en-US", "es-AR", "es-ES", "fi-FI", "fr-FR", "it-IT", "nl-NL", "pt-BR", "zh-CN", "zh-TW"];
const skins           = ["classic"]; // e.g. ["classic", "modern"]
const prefFiles       = ["controledescripts.js"]; // Preferences files, e.g. ["extension.js"]

const silentInstall   = false;
// 'true' installs with no messages

const jarHasSubfolder = false;
// 'true' if jar folder structure is 'content/[shortName]/' or 'false' if jar folder structure is 'content/'. Got it?

var   profileInstall  = true;
// default install type if silentInstall is 'true'

// --- EDITABLE DATA END -----------------------------------


// *** Auxiliar data ************************************
const jarFileName = shortName+".jar";
const profileFolder = getFolder("Profile", "chrome");
const appFolder = getFolder("chrome");
const jarSubfolder = jarHasSubfolder?shortName+"/":"";
var chromeType = null;
var installFolder = null;
var jarFolder = null;

// *** Auxiliar routines ********************************
if (File.exists(getFolder(profileFolder, jarFileName)))
{
	if (!silentInstall)
		alert("Cannot install "+fullName+" "+version+". Please uninstall your previous version first.\n(If you don't know how to uninstall it, visit controledescripts.mozdev.org/uninstall.html)");

	cancelInstall();
}
else
{
	if (!silentInstall)
		profileInstall = confirm("Do you want to install "+fullName+" "+version+" just for this profile?\n(Cancel will install it for all profiles)");

	chromeType = profileInstall?PROFILE_CHROME:DELAYED_CHROME;
	installFolder = profileInstall?profileFolder:appFolder;
	jarFolder = getFolder(installFolder, jarFileName);

	doInstall();
}


// *** Installer ****************************************
function doInstall()
{
	// Begin install
	initInstall(fullName, shortName, version);
	checkError("Couldn't init the installation process.", false);

	// Copy JAR file
	addFile(shortName, "chrome/"+jarFileName, installFolder, null);
	checkError("Couldn't copy "+jarFileName+".\nVerify if you have write access to chrome folder.", false);

	// Register content
	registerChrome(CONTENT | chromeType, jarFolder, "content/"+jarSubfolder);

	// Register locales
	for (var thisOne in locales)
		registerChrome(LOCALE | chromeType, jarFolder, "locale/"+locales[thisOne]+"/"+jarSubfolder);

	// Register skins
	for (var thisOne in skins)
		registerChrome(SKIN | chromeType, jarFolder, "skin/"+skins[thisOne]+"/"+jarSubfolder);

	// Copy preferences files
	for (var thisOne in prefFiles)
		addFile(shortName, "defaults/preferences/"+prefFiles[thisOne], getFolder("Program","defaults/pref/"), null);

	// Finish install
	performInstall();
	checkError("Couldn't install "+fullName+".\nPlease, contact the author about this problem.", true);
}

// *** Auxiliar Functions *******************************
function checkError(errorMsg,isFinalMsg)
{
	var error = getLastError();

	if (isFinalMsg)
	{
		if (error != SUCCESS && error != REBOOT_NEEDED)
		{
			if (!silentInstall)
				alert("Error "+error+"\n"+errorMsg);
			cancelInstall(error);
		}
		else if (!silentInstall)
			alert(fullName+" "+version+" has been installed successfully!");
	}
	else if (error != SUCCESS)
	{
		if (!silentInstall)
			alert("Error "+error+"\n"+errorMsg);
		cancelInstall(error);
	}
}
